@@ -9,23 +9,28 @@ def loadSeries(path_to_series):
     '''Create a series object, fully populated.'''
     if path_to_series.find('/') < 0:
         path_to_series = './' + path_to_series
-    series = loadSeriesXML(path_to_series)
-    series.getSectionsXML(path_to_series)
-    return series
+    try:
+        series = loadSeriesXML(path_to_series)
+        series.getSectionsXML(path_to_series)
+        return series
+    except:
+        print('Error loading series: %s')%path_to_series
     
 def loadSeriesXML(path_to_series):
     '''Creates a series object representation from a .ser XML file in path_to_series'''
     print('Creating series object from ' + path_to_series + '...'),
-    #Parse series
-    tree = ET.parse( path_to_series )
-    
-    root = tree.getroot() #Series
-    #Create series object
-    serName = path_to_series.split('/')[len(path_to_series.split('/'))-1].replace('.ser','')
-    series = Series(root, serName)
-    print('DONE')
-    print('\tSeries: '+series.name)
-    return series
+    try:
+        #Parse series
+        tree = ET.parse( path_to_series )
+        root = tree.getroot() #Series
+        #Create series object
+        serName = path_to_series.split('/')[len(path_to_series.split('/'))-1].replace('.ser','')
+        series = Series(root, serName)
+        print('DONE')
+        print('\tSeries: '+series.name)
+        return series
+    except:
+        print('Error loading sections from: %s')%path_to_series
 
 class Contour:
 # Python Functions
@@ -94,7 +99,7 @@ class Contour:
         if (not self.box().intersects(other.box()) and
             not self.box().touches(other.box()) ):
             return 0
-        # Check if both same class of contours
+        # Check if both same type of contour
         if self.closed != other.closed:
             return 0
         # Closed contours
@@ -863,8 +868,12 @@ class Series:
         for section in self.sections:
             revTraces = []
             for contour in section.contours:
-                if contour.isReverse():
-                    revTraces.append(contour)
+                try:
+                    if contour.isReverse():
+                        revTraces.append(contour)
+                except:
+                        print('Invalid contour (%s on section %d) was ignored')%(contour.name, section.index)
+                        print('\t check coordinates in XML file')
             if len(revTraces) != 0:
                 reverseDict[section.index] = revTraces
         return reverseDict
@@ -912,7 +921,7 @@ class Series:
                     distantTraces[index] = traces
             index += 1
         return distantTraces
-    def locateDuplicates(self): #=== false positives, fix this
+    def locateDuplicates(self):
         '''Locates overlapping traces of the same name in a section. Returns a dictionary of section numbers with duplicates'''
         # Build dictionary of sections w/ contours whose name appear more than once in that section
         duplicateNames = {}
@@ -934,12 +943,12 @@ class Series:
                 # Filter contours of same memory address so that overlap isn't tested on itself
                 copyContours = [cont for cont in duplicateNames[key] if id(cont) != id(contour) and cont.name == contour.name]
                 for cont in copyContours:
-                    try: #===
+                    try:
                         if contour.overlaps(cont) == 1: # Perfect overlap (within threshold)
                             duplicates.append(cont)
-                    except: #===
-                        print('Invalid contour: %s')%cont.name
-                        pause = raw_input('paused, press enter')
+                    except:
+                        print('Invalid contour (%s on section %d) was ignored')%(cont.name, key)
+                        print('\t check coordinates in XML file')
             if len(duplicates) != 0:
                 duplicateDict[key] = duplicates
         return duplicateDict
@@ -1300,11 +1309,15 @@ class Series:
         #Create and add section objects to series
         print('Creating section objects...'),
         for sec in pathlist:
-            secpath = inpath + sec
-            tree = ET.parse(secpath)
-            root = tree.getroot() #Section
-            section = Section(root,sec)
-            self.addsection(section)
+            try:
+                secpath = inpath + sec
+                tree = ET.parse(secpath)
+                root = tree.getroot() #Section
+                section = Section(root,sec)
+                self.addsection(section)
+            except:
+                print('Error loading Section: %s')%inpath+sec
+                quit()
         self.sections = sorted(self.sections, key=lambda Section: Section.index) #sort by index
         print('DONE')
     def zeroIdentity(self):
