@@ -366,137 +366,5 @@ def mergeSectionContours(sA,sB, handler=secContHandler):
     
     return mergedConts
     
-
-def bethBellMerge(path_FPNCT_BB, path_FPNCT_JNB): #===
-    # First load FPNCT_BB and delete everything except those in saveList
-    saveList = [re.compile('[d][0-9]{0,2}vftz[0-9]{0,2}[a-z]?$', re.I), # d##vftz##_
-                re.compile('[d][0-9]{0,2}vftzcfa[0-9]{0,2}[a-z]?$', re.I), # d##vftzcfa##_
-                re.compile('[d][0-9]{0,2}ax[0-9]{0,2}[a-z]?$', re.I), # d##ax##_
-                re.compile('[d][0-9]{0,2}ax[0-9]{0,2}dcv[0-9]{0,2}[a-z]?$', re.I), # d##ax##dcv##_
-                re.compile('[d][0-9]{0,2}ax[0-9]{0,2}dssvdh[0-9]{0,2}[a-z]?$', re.I), # d##ax##dssvdh##_
-                re.compile('[d][0-9]{0,2}ax[0-9]{0,2}dssvrh[0-0]{0,2}[a-z]?$', re.I), # d##ax##dssvrh##_
-                re.compile('[d][0-9]{0,2}ax[0-9]{0,2}dssvrhclose[0-9]{0,2}[a-z]?$', re.I), # d##ax##dssvrhclose##_
-                re.compile('[d][0-9]{0,2}c[0-9]{0,2}[a-z]?$', re.I), # d##c##_
-                re.compile('[d][0-9]{0,2}c[0-9]{0,2}scale[0-9]{0,2}[a-z]?$', re.I), # d##c##scale##_
-                re.compile('[d][0-9]{0,2}cfa[0-9]{0,2}[a-z]?$', re.I)] # d##cfa##_
-    ser1 = loadSeries(path_FPNCT_BB)
-    for section in ser1.sections:
-        savedContours = []
-        for contour in section.contours:
-            for prog in saveList:
-                if len(prog.findall(contour.name)) != 0:
-                    savedContours.append(contour)
-                    break
-        section.contours = savedContours
-    
-    # Now load FPNCT_JNB and delete everything in delList
-    delList = [re.compile('[d][0-9]{0,2}c[0-9]{0,2}[a-z]?$', re.I), # d##c##_
-               re.compile('[d][0-9]{0,2}cfa[0-9]{0,2}[a-z]?$', re.I)] # d##cfa##_
-    
-    ser2 = loadSeries(path_FPNCT_JNB)
-    for section in ser2.sections:
-        deletedContours = []
-        for contour in section.contours:
-            for prog in delList:
-                if len(prog.findall(contour.name)) != 0:
-                    deletedContours.append(contour.name)
-                    break
-        section.contours = [cont for cont in section.contours if cont.name not in deletedContours]
-    
-    ser3 = mergeSeries(ser1, ser2, name='FPNCT_merge')
-    # imageOverride set to 2; imageOverride 1 has different image and domain1 transforms
-    ser3.sections = mergeAllSections(ser1, ser2, name='FPNCT_merge', imageOverride=2)
-    
-    # OUTPUT
-    ser3.writeseries('/home/michaelm/Documents/Test Series/bb/FPNCT_merge/')
-    ser3.writesections('/home/michaelm/Documents/Test Series/bb/FPNCT_merge/')
-    
-class mergeObject: #=== incomplete
-    '''Abstract class to easily change functions for reconstructmergetool.py'''
-    def __init__(self):
-        
-        # META STUFF
-        self.name = 'newSeries'
-        self.outputPath = os.getcwd()+'/'+str(self.name)+'/'
-        
-        # SERIES MERGE FUNCTIONS
-        self.handleSerAtts = serAttHandler
-        self.handleSerConts = serContHandler
-        self.handleSerZConts = serZContHandler
-        
-        # SECTION MERGE FUNCTIONS
-        self.handleSecAtts = secAttHandler
-        self.handleSecImgs = secImgHandler
-        self.handleSecConts = secContHandler
-
-# Fxns
-    def merge(self, path_to_series1, path_to_series2):
-        '''Merges two series together based on mergeObjects' attributes'''
-        s1 = loadSeries(path_to_series1)
-        s2 = loadSeries(path_to_series2)
-
-        mergedSeries = mergeSeries( s1, s2, name = self.name, \
-                                mergeSerAttfxn = self.handleSerAtts, \
-                                mergeSerContfxn = self.handleSerConts, \
-                                mergeSerZContfxn = self.handleSerZConts  )
-        
-        mergedSeries.sections = mergeAllSections( s1, s2, self.name, \
-                                              secAttfxn = self.handleSecAtts, \
-                                              secImgfxn = self.handleSecImgs, \
-                                              secContfxn = self.handleSecConts)
-        mergedSeries.writeseries( self.outputPath )
-        mergedSeries.writesections( self.outputPath )
-        
-# Setters
-    def setName(self, string):
-        self.name = str(string)
-        self.outputPath = os.getcwd()+'/'+str(self.name)+'/'
-        print('Merged series name changed to: '+self.name)
-        print
-        
-    def setOutpath(self, string):
-        self.outputPath = str(string)
-        print('New output path set: '+self.outputPath)
-        print
-        
-    def setSerAttfxn(self, fxn):
-        self.handleSerAtts = fxn
-        print('New series attribute handler set')
-        print
-        
-    def setSerContfxn(self, fxn):
-        self.handleSerConts = fxn
-        print('New series contour handler set')
-        
-    def setSerZContfxn(self, fxn):
-        self.handleSerZConts = fxn
-        print('New series zcontour handler set')
-        
-    def setSecAttfxn(self, fxn):
-        self.handleSecAtts = fxn
-        print('New section attribute handler set')
-        print
-        
-    def setSecImgfxn(self, fxn):
-        self.handleSecImgs = fxn
-        print('New section image handler set')
-        print
-        
-    def setSecContfxn(self, fxn):
-        self.handleSecConts = fxn
-        print('New section contour handler set')
-        print
-    def current(self):
-        print('CURRENT MERGEOBJECT SETTINGS:')
-        print('Name: '+str(self.name))
-        print('Outpath: '+str(self.outputPath))
-        print
-        print('Series Attribute Handler: '+str(self.handleSerAtts))
-        print('Series Contour Handler: '+str(self.handleSerConts))
-        print('Series ZContour Handler: '+str(self.handleSerZConts))
-        print
-        print('Section Attribute Handler: '+str(self.handleSecAtts))
-        print('Section Image Handler: '+str(self.handleSecImgs))
-        print('Section Contour Handler: '+str(self.handleSecConts))
 main()
 
